diff -r 96506cab38bd cocoa/ScintillaView.mm
--- a/cocoa/ScintillaView.mm	Wed Sep 13 11:27:44 2017 +1000
+++ b/cocoa/ScintillaView.mm	Fri Sep 15 19:28:56 2017 +1000
@@ -696,20 +696,18 @@
 //--------------------------------------------------------------------------------------------------
 
 /**
- * Mouse wheel with command key magnifies text.
- * Enabling this code causes visual garbage to appear when scrolling
- * horizontally on OS X 10.9 with a retina display.
- * Pinch gestures and key commands can be used for magnification.
+ * Mouse wheel with command key may magnify text if enabled.
+ * Pinch gestures and key commands can also be used for magnification.
  */
+- (void) scrollWheel: (NSEvent *) theEvent {
 #ifdef SCROLL_WHEEL_MAGNIFICATION
-- (void) scrollWheel: (NSEvent *) theEvent {
 	if (([theEvent modifierFlags] & NSCommandKeyMask) != 0) {
 		mOwner.backend->MouseWheel(theEvent);
-	} else {
-		[super scrollWheel: theEvent];
+		return;
 	}
+#endif
+	[super scrollWheel: theEvent];
 }
-#endif
 
 //--------------------------------------------------------------------------------------------------
 
@@ -728,6 +726,13 @@
 		long lineHeight = mOwner.backend->WndProc(SCI_TEXTHEIGHT, 0, 0);
 		rc.origin.y = roundf(static_cast<XYPOSITION>(rc.origin.y) / lineHeight) * lineHeight;
 	}
+	// Snap to whole points - on retina displays this avoids visual debris
+	// when scrolling horizontally.
+	if ((rc.origin.x > 0) && (NSMaxX(rc) < contentRect.size.width)) {
+		// Only snap for positions inside the document - allow outside
+		// for overshoot.
+		rc.origin.x = roundf(static_cast<XYPOSITION>(rc.origin.x));
+	}
 	return rc;
 }
 
